# @Time     : 2021/11/1
# @Project  : wanba_py
# @IDE      : PyCharm
# @Author   : Angel
# @Email    : 376355670@qq.com
def is_null(value) -> bool:
    return value is None


def is_not_null(value) -> bool:
    return not is_null(value)
